Documentation
¶
Index ¶
- type Cluster
- func (r *Cluster) ClusterCertificates() *pulumi.Output
- func (r *Cluster) ClusterId() *pulumi.StringOutput
- func (r *Cluster) ClusterState() *pulumi.StringOutput
- func (r *Cluster) HsmType() *pulumi.StringOutput
- func (r *Cluster) ID() *pulumi.IDOutput
- func (r *Cluster) SecurityGroupId() *pulumi.StringOutput
- func (r *Cluster) SourceBackupIdentifier() *pulumi.StringOutput
- func (r *Cluster) SubnetIds() *pulumi.ArrayOutput
- func (r *Cluster) Tags() *pulumi.MapOutput
- func (r *Cluster) URN() *pulumi.URNOutput
- func (r *Cluster) VpcId() *pulumi.StringOutput
- type ClusterArgs
- type ClusterState
- type GetClusterArgs
- type GetClusterResult
- type Hsm
- func (r *Hsm) AvailabilityZone() *pulumi.StringOutput
- func (r *Hsm) ClusterId() *pulumi.StringOutput
- func (r *Hsm) HsmEniId() *pulumi.StringOutput
- func (r *Hsm) HsmId() *pulumi.StringOutput
- func (r *Hsm) HsmState() *pulumi.StringOutput
- func (r *Hsm) ID() *pulumi.IDOutput
- func (r *Hsm) IpAddress() *pulumi.StringOutput
- func (r *Hsm) SubnetId() *pulumi.StringOutput
- func (r *Hsm) URN() *pulumi.URNOutput
- type HsmArgs
- type HsmState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cluster ¶
type Cluster struct {
// contains filtered or unexported fields
}
Creates an Amazon CloudHSM v2 cluster.
For information about CloudHSM v2, see the [AWS CloudHSM User Guide][1] and the [Amazon CloudHSM API Reference][2].
~> **NOTE:** CloudHSM can take up to several minutes to be set up. Practically no single attribute can be updated except TAGS. If you need to delete a cluster, you have to remove its HSM modules first. To initialize cluster you have to sign CSR and upload it.
func GetCluster ¶
func GetCluster(ctx *pulumi.Context, name string, id pulumi.ID, state *ClusterState, opts ...pulumi.ResourceOpt) (*Cluster, error)
GetCluster gets an existing Cluster resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewCluster ¶
func NewCluster(ctx *pulumi.Context, name string, args *ClusterArgs, opts ...pulumi.ResourceOpt) (*Cluster, error)
NewCluster registers a new resource with the given unique name, arguments, and options.
func (*Cluster) ClusterCertificates ¶
The list of cluster certificates. * `cluster_certificates.0.cluster_certificate` - The cluster certificate issued (signed) by the issuing certificate authority (CA) of the cluster's owner. * `cluster_certificates.0.cluster_csr` - The certificate signing request (CSR). Available only in UNINITIALIZED state. * `cluster_certificates.0.aws_hardware_certificate` - The HSM hardware certificate issued (signed) by AWS CloudHSM. * `cluster_certificates.0.hsm_certificate` - The HSM certificate issued (signed) by the HSM hardware. * `cluster_certificates.0.manufacturer_hardware_certificate` - The HSM hardware certificate issued (signed) by the hardware manufacturer.
func (*Cluster) ClusterId ¶
func (r *Cluster) ClusterId() *pulumi.StringOutput
The id of the CloudHSM cluster.
func (*Cluster) ClusterState ¶
func (r *Cluster) ClusterState() *pulumi.StringOutput
The state of the cluster.
func (*Cluster) HsmType ¶
func (r *Cluster) HsmType() *pulumi.StringOutput
The type of HSM module in the cluster. Currently, only hsm1.medium is supported.
func (*Cluster) SecurityGroupId ¶
func (r *Cluster) SecurityGroupId() *pulumi.StringOutput
The ID of the security group associated with the CloudHSM cluster.
func (*Cluster) SourceBackupIdentifier ¶
func (r *Cluster) SourceBackupIdentifier() *pulumi.StringOutput
The id of Cloud HSM v2 cluster backup to be restored.
func (*Cluster) SubnetIds ¶
func (r *Cluster) SubnetIds() *pulumi.ArrayOutput
The IDs of subnets in which cluster will operate.
func (*Cluster) VpcId ¶
func (r *Cluster) VpcId() *pulumi.StringOutput
The id of the VPC that the CloudHSM cluster resides in.
type ClusterArgs ¶
type ClusterArgs struct {
// The type of HSM module in the cluster. Currently, only hsm1.medium is supported.
HsmType interface{}
// The id of Cloud HSM v2 cluster backup to be restored.
SourceBackupIdentifier interface{}
// The IDs of subnets in which cluster will operate.
SubnetIds interface{}
Tags interface{}
}
The set of arguments for constructing a Cluster resource.
type ClusterState ¶
type ClusterState struct {
// The list of cluster certificates.
// * `cluster_certificates.0.cluster_certificate` - The cluster certificate issued (signed) by the issuing certificate authority (CA) of the cluster's owner.
// * `cluster_certificates.0.cluster_csr` - The certificate signing request (CSR). Available only in UNINITIALIZED state.
// * `cluster_certificates.0.aws_hardware_certificate` - The HSM hardware certificate issued (signed) by AWS CloudHSM.
// * `cluster_certificates.0.hsm_certificate` - The HSM certificate issued (signed) by the HSM hardware.
// * `cluster_certificates.0.manufacturer_hardware_certificate` - The HSM hardware certificate issued (signed) by the hardware manufacturer.
ClusterCertificates interface{}
// The id of the CloudHSM cluster.
ClusterId interface{}
// The state of the cluster.
ClusterState interface{}
// The type of HSM module in the cluster. Currently, only hsm1.medium is supported.
HsmType interface{}
// The ID of the security group associated with the CloudHSM cluster.
SecurityGroupId interface{}
// The id of Cloud HSM v2 cluster backup to be restored.
SourceBackupIdentifier interface{}
// The IDs of subnets in which cluster will operate.
SubnetIds interface{}
Tags interface{}
// The id of the VPC that the CloudHSM cluster resides in.
VpcId interface{}
}
Input properties used for looking up and filtering Cluster resources.
type GetClusterArgs ¶
type GetClusterArgs struct {
// The id of Cloud HSM v2 cluster.
ClusterId interface{}
// The state of the cluster to be found.
ClusterState interface{}
}
A collection of arguments for invoking getCluster.
type GetClusterResult ¶
type GetClusterResult struct {
// The list of cluster certificates.
// * `cluster_certificates.0.cluster_certificate` - The cluster certificate issued (signed) by the issuing certificate authority (CA) of the cluster's owner.
// * `cluster_certificates.0.cluster_csr` - The certificate signing request (CSR). Available only in UNINITIALIZED state.
// * `cluster_certificates.0.aws_hardware_certificate` - The HSM hardware certificate issued (signed) by AWS CloudHSM.
// * `cluster_certificates.0.hsm_certificate` - The HSM certificate issued (signed) by the HSM hardware.
// * `cluster_certificates.0.manufacturer_hardware_certificate` - The HSM hardware certificate issued (signed) by the hardware manufacturer.
// The number of available cluster certificates may vary depending on state of the cluster.
ClusterCertificates interface{}
ClusterState interface{}
// The ID of the security group associated with the CloudHSM cluster.
SecurityGroupId interface{}
// The IDs of subnets in which cluster operates.
SubnetIds interface{}
// The id of the VPC that the CloudHSM cluster resides in.
VpcId interface{}
// id is the provider-assigned unique ID for this managed resource.
Id interface{}
}
A collection of values returned by getCluster.
func LookupCluster ¶
func LookupCluster(ctx *pulumi.Context, args *GetClusterArgs) (*GetClusterResult, error)
Use this data source to get information about a CloudHSM v2 cluster
type Hsm ¶
type Hsm struct {
// contains filtered or unexported fields
}
Creates an HSM module in Amazon CloudHSM v2 cluster.
func GetHsm ¶
func GetHsm(ctx *pulumi.Context, name string, id pulumi.ID, state *HsmState, opts ...pulumi.ResourceOpt) (*Hsm, error)
GetHsm gets an existing Hsm resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewHsm ¶
func NewHsm(ctx *pulumi.Context, name string, args *HsmArgs, opts ...pulumi.ResourceOpt) (*Hsm, error)
NewHsm registers a new resource with the given unique name, arguments, and options.
func (*Hsm) AvailabilityZone ¶
func (r *Hsm) AvailabilityZone() *pulumi.StringOutput
The IDs of AZ in which HSM module will be located. Do not use together with subnet_id.
func (*Hsm) ClusterId ¶
func (r *Hsm) ClusterId() *pulumi.StringOutput
The ID of Cloud HSM v2 cluster to which HSM will be added.
func (*Hsm) HsmEniId ¶
func (r *Hsm) HsmEniId() *pulumi.StringOutput
The id of the ENI interface allocated for HSM module.
func (*Hsm) IpAddress ¶
func (r *Hsm) IpAddress() *pulumi.StringOutput
The IP address of HSM module. Must be within the CIDR of selected subnet.
func (*Hsm) SubnetId ¶
func (r *Hsm) SubnetId() *pulumi.StringOutput
The ID of subnet in which HSM module will be located.
type HsmArgs ¶
type HsmArgs struct {
// The IDs of AZ in which HSM module will be located. Do not use together with subnet_id.
AvailabilityZone interface{}
// The ID of Cloud HSM v2 cluster to which HSM will be added.
ClusterId interface{}
// The IP address of HSM module. Must be within the CIDR of selected subnet.
IpAddress interface{}
// The ID of subnet in which HSM module will be located.
SubnetId interface{}
}
The set of arguments for constructing a Hsm resource.
type HsmState ¶
type HsmState struct {
// The IDs of AZ in which HSM module will be located. Do not use together with subnet_id.
AvailabilityZone interface{}
// The ID of Cloud HSM v2 cluster to which HSM will be added.
ClusterId interface{}
// The id of the ENI interface allocated for HSM module.
HsmEniId interface{}
// The id of the HSM module.
HsmId interface{}
// The state of the HSM module.
HsmState interface{}
// The IP address of HSM module. Must be within the CIDR of selected subnet.
IpAddress interface{}
// The ID of subnet in which HSM module will be located.
SubnetId interface{}
}
Input properties used for looking up and filtering Hsm resources.